==> moodle-1.5-pgsql.tgz: moodle/lang/ja_utf8/grades.php <==
<?PHP // $Id$ 
      // grades.php - created with Moodle 1.6 development (2005060201)


$string['addcategory'] = 'カテゴリの追加';
$string['addcategoryerror'] = 'カテゴリを追加できませんでした。';
$string['addexceptionerror'] = 'ユーザID:評定項目に例外を追加中にエラーが発生しました。';
$string['allgrades'] = 'カテゴリ毎の評点';
$string['allstudents'] = '全ての学生';
$string['average'] = '平均';
$string['bonuspoints'] = 'ボーナスポイント';
$string['categories'] = 'カテゴリ';
$string['category'] = 'カテゴリ';
$string['choosecategory'] = 'カテゴリの選択';
$string['creatinggradebooksettings'] = '評定表設定の作成';
$string['curveto'] = 'カーブ';
$string['deletecategory'] = 'カテゴリの削除';
$string['displaylettergrade'] = '評定文字を表示する';
$string['displaypercent'] = 'パーセントを表示する';
$string['displaypoints'] = 'ポイントを表示する';
$string['displayweighted'] = '比重評点を表示する';
$string['dropped'] = '下落';
$string['dropxlowest'] = '下落 X 最低';
$string['dropxlowestwarning'] = '注意: 「下落 X 最低」を使用する場合、カテゴリ内の全ての項目は同じ点数だとみなされます。もし、各項目の点数が異なる場合、結果は保証されません。';
$string['errorgradevaluenonnumeric'] = '低いまたは高い評点が数値ではありません:';
$string['errornocategorizedid'] = 'カテゴリ無しIDを取得できませんでした!';
$string['errornocourse'] = 'コース情報を取得できませんでした。';
$string['errorreprintheadersnonnumeric'] = 'Reprintヘッダが数値ではありません:';
$string['exceptions'] = '例外';
$string['excluded'] = '除外';
$string['extracredit'] = '自己申告';
$string['extracreditwarning'] = '注意: カテゴリ内の全ての項目を自己申告にすることにより、評定の計算から項目を効果的に除外することができます。これにより合計点数は計算されません。';
$string['forstudents'] = '学生に対して';
$string['gradebook'] = '評定表';
$string['gradebookhiddenerror'] = '現在、評定表は学生から隠されています。';
$string['gradecategoryhelp'] = '評定カテゴリヘルプ';
$string['gradeexceptions'] = '例外設定';
$string['gradeexceptionshelp'] = '評定例外ヘルプ';
$string['gradehelp'] = '評定ヘルプ';
$string['gradeitem'] = '評定項目';
$string['gradeitemaddusers'] = '評定から除外する';
$string['gradeitemmembersselected'] = '評定から除外する';
$string['gradeitemnonmembers'] = '評定に含める';
$string['gradeitemremovemembers'] = '評定に含める';
$string['gradeitems'] = '評定項目';
$string['gradeletter'] = '評定文字';
$string['gradeletterhelp'] = '評定文字ヘルプ';
$string['gradeletternote'] = '評定文字を削除するには、テキストエリアの文字を<br />空白にして「変更を保存」をクリックしてください。';
$string['gradepreferenceshelp'] = '評定オプションヘルプ';
$string['grades'] = '評定';
$string['gradeweighthelp'] = '評定比重ヘルプ';
$string['hideadvanced'] = '拡張機能を隠す';
$string['hidecategory'] = '隠す';
$string['highgradeascending'] = '高評点の昇順で並び替え';
$string['highgradedescending'] = '高評点の降順で並び替え';
$string['highgradeletter'] = '高い';
$string['incorrectcourseid'] = 'コースIDが間違っています。';
$string['item'] = '項目';
$string['items'] = '項目';
$string['lettergrade'] = '評定文字';
$string['lettergradenonnumber'] = '低い/高い評点は数値ではありません:';
$string['letters'] = '文字';
$string['lowest'] = '最低';
$string['lowgradeletter'] = '低い';
$string['max'] = '再考';
$string['maxgrade'] = '最大評点';
$string['median'] = '中間';
$string['min'] = '最低';
$string['mode'] = 'モード';
$string['no'] = 'No';
$string['nocategories'] = 'このコースに評定カテゴリは追加されなかったか、見つかりませんでした。';
$string['nocategoryview'] = 'カテゴリがありません。';
$string['nogradeletters'] = '評定文字ガ設定されていません。';
$string['nogradesreturned'] = '評定がありません。';
$string['nolettergrade'] = '評定文字がありません:';
$string['nomode'] = 'NA';
$string['nonnumericweight'] = '数値ではありません:';
$string['nonweightedpct'] = '比重無し%%';
$string['pctoftotalgrade'] = '評点合計の%%';
$string['percent'] = 'パーセント';
$string['percentascending'] = 'パーセントの昇順で並び替え';
$string['percentdescending'] = 'パーセントの降順で並び替え';
$string['percentshort'] = '%%';
$string['points'] = '点数';
$string['pointsascending'] = '点数の昇順で並び替え';
$string['pointsdescending'] = '点数の降順で並び替え';
$string['preferences'] = 'オプション';
$string['rawpct'] = '実%%';
$string['reprintheaders'] = 'ヘッダの再表示';
$string['savechanges'] = '変更を保存';
$string['savepreferences'] = '設定を保存';
$string['scaledpct'] = '伸縮%%';
$string['setcategories'] = 'カテゴリの設定';
$string['setcategorieserror'] = '比重を与える前にコースにカテゴリを設定してください。';
$string['setgradeletters'] = '評定文字の設定';
$string['setpreferences'] = 'オプション設定';
$string['setting'] = '設定';
$string['settings'] = '設定';
$string['setweights'] = '比重の設定';
$string['showallstudents'] = '全ての学生を表示';
$string['showhiddenitems'] = '隠し項目を表示する';
$string['sort'] = '並び替え';
$string['sortbyfirstname'] = '名で並べ替え';
$string['sortbylastname'] = '姓で並び替え';
$string['standarddeviation'] = '標準偏差';
$string['stats'] = '統計';
$string['statslink'] = '統計';
$string['student'] = '学生';
$string['total'] = '合計';
$string['totalweight100'] = '合計比重は100です。';
$string['totalweightnot100'] = '合計比重は100ではありません。';
$string['uncategorised'] = 'カテゴリ無し';
$string['useadvanced'] = '拡張機能を表示';
$string['usepercent'] = 'パーセントを使用';
$string['useweighted'] = '比重を使用';
$string['viewbygroup'] = 'グループ';
$string['viewgrades'] = '評定の表示';
$string['weight'] = 'ウェイト';
$string['weightedascending'] = '比重パーセントの昇順で並び替え';
$string['weighteddescending'] = '比重パーセントの降順で並び替え';
$string['weightedpct'] = '比重%%';
$string['weightedpctcontribution'] = '比重%%貢献';
$string['writinggradebookinfo'] = '評定表設定の書き込み';
$string['yes'] = 'Yes';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ja_utf8/grades.php <==
<?PHP // $Id$ 
      // grades.php - created with Moodle 1.6 development (2005060201)


$string['addcategory'] = 'カテゴリの追加';
$string['addcategoryerror'] = 'カテゴリを追加できませんでした。';
$string['addexceptionerror'] = 'ユーザID:評定項目に例外を追加中にエラーが発生しました。';
$string['allgrades'] = 'カテゴリ毎の評点';
$string['allstudents'] = '全ての学生';
$string['average'] = '平均';
$string['bonuspoints'] = 'ボーナスポイント';
$string['categories'] = 'カテゴリ';
$string['category'] = 'カテゴリ';
$string['choosecategory'] = 'カテゴリの選択';
$string['creatinggradebooksettings'] = '評定表設定の作成';
$string['curveto'] = 'カーブ';
$string['deletecategory'] = 'カテゴリの削除';
$string['displaylettergrade'] = '評定文字を表示する';
$string['displaypercent'] = 'パーセントを表示する';
$string['displaypoints'] = '評点を表示する';
$string['displayweighted'] = '比重評点を表示する';
$string['dropped'] = '除外';
$string['dropxlowest'] = '下位X件の除外';
$string['dropxlowestwarning'] = '注意: 「下位X件の除外」を使用する場合、カテゴリ内の全ての項目は同じ点数の値を持つとみなされます。もし、各項目の点数の値が異なる場合、結果は保証されません。';
$string['errorgradevaluenonnumeric'] = '低いまたは高い評点が数値ではありません:';
$string['errornocategorizedid'] = 'カテゴリ無しIDを取得できませんでした!';
$string['errornocourse'] = 'コース情報を取得できませんでした。';
$string['errorreprintheadersnonnumeric'] = 'ヘッダの再表示の値が数値ではありません:';
$string['exceptions'] = '例外';
$string['excluded'] = '除外';
$string['extracredit'] = '自己申告';
$string['extracreditwarning'] = '注意: カテゴリ内の全ての項目を自己申告にすることにより、評定の計算から項目を効果的に除外することができます。これにより合計点数は計算されません。';
$string['forstudents'] = '学生に対して';
$string['gradebook'] = '評定表';
$string['gradebookhiddenerror'] = '現在、評定表は学生から隠されています。';
$string['gradecategoryhelp'] = '評定カテゴリヘルプ';
$string['gradeexceptions'] = '例外設定';
$string['gradeexceptionshelp'] = '評定例外ヘルプ';
$string['gradehelp'] = '評定ヘルプ';
$string['gradeitem'] = '評定項目';
$string['gradeitemaddusers'] = '評定から除外する';
$string['gradeitemmembersselected'] = '評定から除外する';
$string['gradeitemnonmembers'] = '評定対象とする';
$string['gradeitemremovemembers'] = '評定対象とする';
$string['gradeitems'] = '評定項目';
$string['gradeletter'] = '評定文字';
$string['gradeletterhelp'] = '評定文字ヘルプ';
$string['gradeletternote'] = '評定文字を削除するには、テキストエリアの文字を<br />空白にして「変更を保存」をクリックしてください。';
$string['gradepreferenceshelp'] = '評定オプションヘルプ';
$string['grades'] = '評定';
$string['gradeweighthelp'] = '評定比重ヘルプ';
$string['hideadvanced'] = '拡張機能を隠す';
$string['hidecategory'] = '隠す';
$string['highgradeascending'] = '高評点の昇順で並び替え';
$string['highgradedescending'] = '高評点の降順で並び替え';
$string['highgradeletter'] = '高い';
$string['incorrectcourseid'] = 'コースIDが間違っています。';
$string['item'] = '項目';
$string['items'] = '項目';
$string['lettergrade'] = '評定文字';
$string['lettergradenonnumber'] = '低い/高い評点は数値ではありません:';
$string['letters'] = '文字';
$string['lowest'] = '最低';
$string['lowgradeletter'] = '低い';
$string['max'] = '最高';
$string['maxgrade'] = '最大評点';
$string['median'] = '中央値';
$string['min'] = '最低';
$string['mode'] = '最頻値';
$string['no'] = 'No';
$string['nocategories'] = 'このコースに評定カテゴリは追加されなかったか、見つかりませんでした。';
$string['nocategoryview'] = 'カテゴリがありません。';
$string['nogradeletters'] = '評定文字ガ設定されていません。';
$string['nogradesreturned'] = '評定がありません。';
$string['nolettergrade'] = '評定文字がありません:';
$string['nomode'] = 'NA';
$string['nonnumericweight'] = '数値ではありません:';
$string['nonweightedpct'] = '比重無し%%';
$string['pctoftotalgrade'] = '評点合計の%%';
$string['percent'] = 'パーセント';
$string['percentascending'] = 'パーセントの昇順で並び替え';
$string['percentdescending'] = 'パーセントの降順で並び替え';
$string['percentshort'] = '%%';
$string['points'] = '点数';
$string['pointsascending'] = '点数の昇順で並び替え';
$string['pointsdescending'] = '点数の降順で並び替え';
$string['preferences'] = 'オプション';
$string['rawpct'] = '実%%';
$string['reprintheaders'] = 'ヘッダの再表示';
$string['savechanges'] = '変更を保存';
$string['savepreferences'] = '設定を保存';
$string['scaledpct'] = '伸縮%%';
$string['setcategories'] = 'カテゴリの設定';
$string['setcategorieserror'] = '比重を与える前にコースにカテゴリを設定してください。';
$string['setgradeletters'] = '評定文字の設定';
$string['setpreferences'] = 'オプション設定';
$string['setting'] = '設定';
$string['settings'] = '設定';
$string['setweights'] = '比重の設定';
$string['showallstudents'] = '全ての学生を表示';
$string['showhiddenitems'] = '隠し項目を表示する';
$string['sort'] = '並び替え';
$string['sortbyfirstname'] = '名で並び替え';
$string['sortbylastname'] = '姓で並び替え';
$string['standarddeviation'] = '標準偏差';
$string['stats'] = '統計';
$string['statslink'] = '統計';
$string['student'] = '学生';
$string['total'] = '合計';
$string['totalweight100'] = '比重合計は100です。';
$string['totalweightnot100'] = '比重合計は100ではありません。';
$string['uncategorised'] = 'カテゴリ無し';
$string['useadvanced'] = '拡張機能を表示';
$string['usepercent'] = 'パーセントを使用';
$string['useweighted'] = '比重を使用';
$string['viewbygroup'] = 'グループ';
$string['viewgrades'] = '評定の表示';
$string['weight'] = '比重';
$string['weightedascending'] = '比重パーセントの昇順で並び替え';
$string['weighteddescending'] = '比重パーセントの降順で並び替え';
$string['weightedpct'] = '比重%%';
$string['weightedpctcontribution'] = '比重%%適用';
$string['writinggradebookinfo'] = '評定表設定の書き込み';
$string['yes'] = 'Yes';

?>
